@@ -1,7 +1,9 @@
-""" Pair related code """
+"""Pair related code."""
+
+
+class Pair:
+    """Pair object."""
 
-class Pair():
-    """ Pair """
     def __init__(self, base: str, quote: str):
         self.base = base
         self.quote = quote
